@@ -10,14 +10,13 @@
 //!
 //! Lembaran lets you pick which utilities you need via Cargo feature.
 //!
-//! - `lembaran_web_linking`, includes types to extract RFC 8288: Web Linking from HTTP header.
-//! - `http`, includes support for `http` crate types, enables `lembaran_web_linking`.
-//! - `http-types`, includes support for `http-types` crate types, enables `lembaran_web_linking`.
+//! - `web_linking`, includes types to extract RFC 8288: Web Linking from HTTP header.
+//! - `ext_http`, includes support for `http` crate types, enables `web_linking`.
+//! - `ext_http-types`, includes support for `http-types` crate types, enables `web_linking`.
 //! - `stream`, includes types for creating async stream for paged responses.
-//!
 
 #[cfg(feature = "stream")]
 pub mod stream;
 
-#[cfg(feature = "lembaran_web_linking")]
+#[cfg(feature = "web_linking")]
 pub mod web_linking;
